You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@labs.apache.org by be...@apache.org on 2008/11/22 22:09:47 UTC

svn commit: r719918 - in /labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery: ServiceDiscoveryInfoDictionary.java ServiceDiscoveryItemDictionary.java ServiceDiscoveryModule.java

Author: berndf
Date: Sat Nov 22 13:09:47 2008
New Revision: 719918

URL: http://svn.apache.org/viewvc?rev=719918&view=rev
Log:
[vysper] LABS-228 activate item handler

Added:
    labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryInfoDictionary.java
      - copied, changed from r713443, labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryDictionary.java
    labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryItemDictionary.java
Modified:
    labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryModule.java

Copied: labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryInfoDictionary.java (from r713443, labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryDictionary.java)
URL: http://svn.apache.org/viewvc/labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryInfoDictionary.java?p2=labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryInfoDictionary.java&p1=labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryDictionary.java&r1=713443&r2=719918&rev=719918&view=diff
==============================================================================
--- labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryItemDictionary.java (added)
+++ labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryItemDictionary.java Sat Nov 22 13:09:47 2008
@@ -0,0 +1,32 @@
+/***********************************************************************
+ * Copyright (c) 2006-2007 The Apache Software Foundation.             *
+ * All rights reserved.                                                *
+ * ------------------------------------------------------------------- *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you *
+ * may not use this file except in compliance with the License. You    *
+ * may obtain a copy of the License at:                                *
+ *                                                                     *
+ *     http://www.apache.org/licenses/LICENSE-2.0                      *
+ *                                                                     *
+ * Unless required by applicable law or agreed to in writing, software *
+ * distributed under the License is distributed on an "AS IS" BASIS,   *
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or     *
+ * implied.  See the License for the specific language governing       *
+ * permissions and limitations under the License.                      *
+ ***********************************************************************/
+
+package org.apache.vysper.xmpp.modules.servicediscovery;
+
+import org.apache.vysper.xmpp.modules.servicediscovery.handler.DiscoItemIQHandler;
+import org.apache.vysper.xmpp.protocol.NamespaceHandlerDictionary;
+import org.apache.vysper.xmpp.protocol.NamespaceURIs;
+
+/**
+ * handler for service discovery item (XEP-0030)
+ */
+public class ServiceDiscoveryItemDictionary extends NamespaceHandlerDictionary {
+
+    public ServiceDiscoveryItemDictionary() {
+        super(NamespaceURIs.XEP0030_SERVICE_DISCOVERY_ITEMS, new DiscoItemIQHandler());
+    }
+}
\ No newline at end of file

Modified: labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryModule.java
URL: http://svn.apache.org/viewvc/labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryModule.java?rev=719918&r1=719917&r2=719918&view=diff
==============================================================================
--- labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryModule.java (original)
+++ labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryModule.java Sat Nov 22 13:09:47 2008
@@ -28,17 +28,20 @@
  */
 public class ServiceDiscoveryModule extends DefaultModule {
 
+    @Override
     public String getName() {
         return "servicediscovery";
     }
 
+    @Override
     public String getVersion() {
         return "1.0beta";
     }
 
     @Override
     protected void addHandlerDictionaries(List<HandlerDictionary> dictionary) {
-        dictionary.add(new ServiceDiscoveryDictionary());
+        dictionary.add(new ServiceDiscoveryInfoDictionary());
+        dictionary.add(new ServiceDiscoveryItemDictionary());
     }
 
     @Override



---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@labs.apache.org
For additional commands, e-mail: commits-help@labs.apache.org
--- labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryDictionary.java (original)
+++ labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryInfoDictionary.java Sat Nov 22 13:09:47 2008
@@ -22,11 +22,11 @@
 import org.apache.vysper.xmpp.protocol.NamespaceURIs;
 
 /**
  * handler for service discovery (XEP-0030)
  */
-public class ServiceDiscoveryDictionary extends NamespaceHandlerDictionary {
+public class ServiceDiscoveryInfoDictionary extends NamespaceHandlerDictionary {
 
-    public ServiceDiscoveryDictionary() {
+    public ServiceDiscoveryInfoDictionary() {
         super(NamespaceURIs.XEP0030_SERVICE_DISCOVERY_INFO, new DiscoInfoIQHandler());
     }
 }
@@ -22,11 +22,11 @@
 
 /**
- * handler for service discovery (XEP-0030)
+ * handler for service discovery info (XEP-0030)
  */
\ No newline at end of file

Added: labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryItemDictionary.java
URL: http://svn.apache.org/viewvc/labs/vysper/src/main/java/org/apache/vysper/xmpp/modules/servicediscovery/ServiceDiscoveryItemDictionary.java?rev=719918&view=auto
==============================================================================